.. :changelog:

Shiba : Python API for PriceMinister WebServices
================================================

Version 1.2.0
-------------------

Released on XXX 2021

- Reformat code using `black`
- Compatibility to python 3.9
- Removes python 3.4, 3.5

Version 1.1.12
-------------------

Released on November 19 2018

- Fix utf8 py3 way

Version 1.1.11
-------------------

Released on October 30 2018

- Add python3.7 support
- Drop support for python27 and python33
- Fix documentation
- Merge 'bypass xmlcreation' from tboulogne
- Change endpoints to rakuten

Version 1.1.10
--------------

Released on February 21st 2017

- Fix malformed xml

Version 1.1.9
-------------

Released on December 15th 2016

- Used furl to manipulate URLs

Version 1.1.8
-------------

Released on December 14th 2016

- Fix encoding in urlencode

Version 1.1.7
-------------

Released on November 08th 2016

- Fix broken pypi package

Version 1.1.6
-------------

Released on August 10th 2016

- Updated the webservices versions

Version 1.1.5
-------------

Released on July 21st 2016

- Python 3 support
